<?php
  
/**
 * @file
 * Administration interface
 */

/**
 * Form builder for the main settings form.
 *
 * @see advlf_settings_form_validate()
 * 
 * @ingroup forms
 */
function advlf_settings_form($form_state) {
  $form = array();
  
  $form['filter_advlf_external_setting'] = array(
    '#title' => t('External link behavior'),
    '#type' => 'radios',
    '#options' => array(
      '' => t('Do nothing'),
      'target' => t('Add target attribute, set to <em>_blank</em> (not HTML strict compliant)'),
      'javascript' => t('Use javascript to open in a new window (HTML strict compliant)'),
    ),
    '#default_value' => variable_get('filter_advlf_external_setting', ''),
  );
  
  $form['filter_advlf_internal_domains'] = array(
    '#title' => t('Specify the domains that should not be considered as external'),
    '#type' => 'textarea',
    '#default_value' => variable_get('filter_advlf_internal_domains', ''),
    '#description' => t('Add one domain per line, including the scheme (for example <em>http://</em>). Do not add trainling slash. You may use the character * as wildcards, except in the URL scheme.'),
  );
  
  return system_settings_form($form);
}

/**
 * Form validation handler for the main settings form.
 *
 * @see advlf_settings_form()
 */
function advlf_settings_form_validate($form, &$form_state) {
  $domains = preg_split('~\s+~', $form_state['values']['filter_advlf_internal_domains']);
  
  // Removes trailing slashes.
  $domains = array_map(create_function('$string', 'return rtrim($string, "/");'), $domains);
  
  // Removes empty lines.
  $domains = array_filter($domains, 'strlen');
  
  // Gets external domains.
  $external = array_filter($domains, 'advlf_valid_domain');
  
  // Checks errors.
  if ($errors = array_diff($domains, $external)) {
    form_set_error('filter_advlf_internal_domains', format_plural(count($errors), 'The following doamin is invalid: %errors.', 'The following doamins are invalid: %errors.', array('%errors' => implode(', ', $errors))));
  }
  else {
    form_set_value($form['filter_advlf_internal_domains'], implode("\n", array_unique($domains)), $form_state);
  }
}
